==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/ListJobExecutionsForJobResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListJobExecutionsForJobResponse(
    executionSummaries: Optional[
      Iterable[zio.aws.iot.model.JobExecutionSummaryForJob]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse = {
    import ListJobExecutionsForJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
      .builder()
      .optionallyWith(
        executionSummaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.executionSummaries)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ListJobExecutionsForJobResponse.ReadOnly =
    zio.aws.iot.model.ListJobExecutionsForJobResponse.wrap(buildAwsValue())
}
object ListJobExecutionsForJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListJobExecutionsForJobResponse =
      zio.aws.iot.model.ListJobExecutionsForJobResponse(
        executionSummaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def executionSummaries
        : Optional[List[zio.aws.iot.model.JobExecutionSummaryForJob.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getExecutionSummaries: ZIO[Any, AwsError, List[
      zio.aws.iot.model.JobExecutionSummaryForJob.ReadOnly
    ]] = AwsError.unwrapOptionField("executionSummaries", executionSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
  ) extends zio.aws.iot.model.ListJobExecutionsForJobResponse.ReadOnly {
    override val executionSummaries
        : Optional[List[zio.aws.iot.model.JobExecutionSummaryForJob.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.executionSummaries())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iot.model.JobExecutionSummaryForJob.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
  ): zio.aws.iot.model.ListJobExecutionsForJobResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iot_3-5.17.104.11-sources.jar: zio/aws/iot/model/ListJobExecutionsForJobResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListJobExecutionsForJobResponse(
    executionSummaries: Option[
      Iterable[zio.aws.iot.model.JobExecutionSummaryForJob]
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse = {
    import ListJobExecutionsForJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
      .builder()
      .optionallyWith(
        executionSummaries.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.executionSummaries)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ListJobExecutionsForJobResponse.ReadOnly =
    zio.aws.iot.model.ListJobExecutionsForJobResponse.wrap(buildAwsValue())
}
object ListJobExecutionsForJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListJobExecutionsForJobResponse =
      zio.aws.iot.model.ListJobExecutionsForJobResponse(
        executionSummaries.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def executionSummaries
        : Option[List[zio.aws.iot.model.JobExecutionSummaryForJob.ReadOnly]]
    def nextToken: Option[NextToken]
    def getExecutionSummaries: ZIO[Any, AwsError, List[
      zio.aws.iot.model.JobExecutionSummaryForJob.ReadOnly
    ]] = AwsError.unwrapOptionField("executionSummaries", executionSummaries)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
  ) extends zio.aws.iot.model.ListJobExecutionsForJobResponse.ReadOnly {
    override val executionSummaries
        : Option[List[zio.aws.iot.model.JobExecutionSummaryForJob.ReadOnly]] =
      scala
        .Option(impl.executionSummaries())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iot.model.JobExecutionSummaryForJob.wrap(item)
          }.toList
        )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListJobExecutionsForJobResponse
  ): zio.aws.iot.model.ListJobExecutionsForJobResponse.ReadOnly = new Wrapper(
    impl
  )
}
